<?php
# This function escapes data that we're wanting to send to MySQL
#
# Written by:
# Joey kelly, joey@joeykelly.net
#
#
function escapesqldata($sqlvar) {
  # here we're adding slashes to escape quotes, NULL values, etc. 
  $sqlvar = mysql_escape_string($sqlvar);
  # next we get rid of semicolons to combat SQL injection attacks
#  $sqlvar = str_replace(';', '', $sqlvar);
  return($sqlvar);
}
?>
