<?php
# header file for invoice web app
?>
<!doctype html public "-//w3c//dtd html 4.0 transitional//en">
<html>
<head>
  <meta http-equiv="Content-Type" content="text/css; charset=iso-8859-1">
  <meta name="GENERATOR" content="wrote by hand">
  <title>(<?= $title ?>) KellyNet Computer Services: invoices by WebInvoicer 0.5.2</title>
</head>
<body style="font-size: small">


<?php
include ("license.inc");
?>

<div align="center">
<font color="#009900">
<big><big><b>WebInvoicer 0.5.2</big><br>
Web-based "Point-of-Sale" application</big><br>
written by <a href="http://joeykelly.net">Joey Kelly</a>, copyright 2004</b>
</font>
</div>
<hr>

<?php
# any more?
?>
