<?php
#

# the function that processes POST variables
include('getpostvars.inc');

# here we send our POST variables off to be processed
$task			= getpostvars('task', 16);

include ("header.inc");
#
include ("database.inc");
#
# first we find out what task we want to accomplish
?>
<h2>What do you want to do?</h2>

<h3>Company Tasks</h3>
<ul>
  <li><a href="addcompany.php">Add a company to the database</a>
  <li><a href="choosecompany.php">Choose a company and create an invoice</a>
</ul>

<h3>Invoice Tasks</h3>
<ul>
  <li><form action="printinvoice.php" method="POST" enctype="text">
	    <b>Print an invoice: </b>
		<input type="text" name="transaction_id" size=11>
		<input type=submit value="Print Invoice">
	  </form>
</ul>



<?php
#
#include ("cleanfoot.inc");
#
?>




